@@ -13,11 +13,11 @@ class BLZWDecompressor : public XPKDecompressor
 public:
 	BLZWDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify);
 
-	virtual ~BLZWDecompressor();
+	~BLZWDecompressor() noexcept=default;
 
-	virtual const std::string &getSubName() const noexcept override final;
+	const std::string &getSubName() const noexcept final;
 
-	virtual void decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify) override final;
+	void decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify) final;
 
 	static bool detectHeaderXPK(uint32_t hdr);
 	static std::shared_ptr<XPKDecompressor> create(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify);
@@ -25,8 +25,8 @@ public:
 private:
 	const Buffer	&_packedData;
 
-	uint32_t	_maxBits=0;
-	uint32_t	_stackLength=0;
+	uint32_t	_maxBits{0};
+	uint32_t	_stackLength{0};
 };
 
 }
