@@ -11,11 +11,11 @@
 namespace ancient::internal
 {
 
-bool CompactDecompressor::detectHeader(uint32_t hdr) noexcept
+bool CompactDecompressor::detectHeader(uint32_t hdr,uint32_t footer) noexcept
 {
-	// If a compact file has signature of 0x1fff it means the its endianess is wrongly configured
+	// If a compact file has signature of 0x1fff it means the its endianness is wrongly configured
 	// (This is easy since it only knows of vax and pdp-11)
-	// Files with a wrong endianess are almost salvageable - they just wrongly encode first and last byte
+	// Files with a wrong endianness are almost salvageable - they just wrongly encode first and last byte
 	// Thus supporting them would be in vain
 	return (hdr>>16)==0xff1fU;
 }
@@ -32,7 +32,7 @@ CompactDecompressor::CompactDecompressor(const Buffer &packedData,bool exactSize
 	if (_packedData.size()<2U)
 		throw InvalidFormatError();
 	uint32_t hdr{_packedData.readBE16(0)};
-	if (!detectHeader(hdr<<16))
+	if (!detectHeader(hdr<<16,0))
 		throw InvalidFormatError();
 	if (exactSizeKnown)
 		_packedSize=packedData.size();
