@@ -52,7 +52,7 @@ public:
 	void decompress(Buffer &rawData,bool verify);
 
 	// in case of disk image based formats the data does not necessarily start
-	// from logical beginnig of the image but it is offsetted inside the logical image
+	// from logical beginning of the image but it is offsetted inside the logical image
 	// (f.e. DMS). getDataOffset will return the offset (or 0 if not relevant or if offset does not exist)
 	// getImageSize will return the size of the the logical image, or 0 if not image-based format
 	virtual size_t getImageSize() const noexcept;
@@ -74,8 +74,8 @@ public:
 	static std::shared_ptr<Decompressor> create(const Buffer &packedData,bool exactSizeKnown,bool verify);
 
 	// Detect signature whether it matches to any known compressor
-	// This does not guarantee the data is decompressable though, only signature is read
-	static bool detect(const Buffer &packedData) noexcept;
+	// This does not guarantee the data is decompressable though, only signature(s) is read
+	static bool detect(const Buffer &packedData,bool exactSizeKnown) noexcept;
 
 protected:
 	virtual void decompressImpl(Buffer &rawData,bool verify)=0;
