@@ -21,34 +21,31 @@ std::shared_ptr<XPKDecompressor> HUFFDecompressor::create(uint32_t hdr,uint32_t
 }
 
 HUFFDecompressor::HUFFDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify) :
-	XPKDecompressor(recursionLevel),
-	_packedData(packedData)
+	XPKDecompressor{recursionLevel},
+	_packedData{packedData}
 {
 	if (!detectHeaderXPK(hdr) || packedData.size()<6)
 		throw Decompressor::InvalidFormatError();
 	// version: only 0 is defined
-	uint16_t ver=packedData.readBE16(0);
-	if (ver) throw Decompressor::InvalidFormatError();
+	uint16_t ver{packedData.readBE16(0)};
+	if (ver)
+		throw Decompressor::InvalidFormatError();
 	// password: we do not support it...
-	uint32_t pwd=packedData.readBE32(2);
-	if (pwd!=0xabadcafe) throw Decompressor::InvalidFormatError();
-}
-
-HUFFDecompressor::~HUFFDecompressor()
-{
-	// nothing needed
+	uint32_t pwd{packedData.readBE32(2)};
+	if (pwd!=0xabadcafe)
+		throw Decompressor::InvalidFormatError();
 }
 
 const std::string &HUFFDecompressor::getSubName() const noexcept
 {
-	static std::string name="XPK-HUFF: Huffman compressor";
+	static std::string name{"XPK-HUFF: Huffman compressor"};
 	return name;
 }
 
 void HUFFDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify)
 {
-	ForwardInputStream inputStream(_packedData,6,_packedData.size());
-	MSBBitReader<ForwardInputStream> bitReader(inputStream);
+	ForwardInputStream inputStream{_packedData,6,_packedData.size()};
+	MSBBitReader<ForwardInputStream> bitReader{inputStream};
 	auto readBit=[&]()->uint32_t
 	{
 		return bitReader.readBits8(1);
@@ -58,23 +55,24 @@ void HUFFDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData
 		return inputStream.readByte();
 	};
 
-	ForwardOutputStream outputStream(rawData,0,rawData.size());
+	ForwardOutputStream outputStream{rawData,0,rawData.size()};
 
-	HuffmanDecoder<uint32_t> decoder;
+	HuffmanDecoder<uint8_t> decoder;
 	for (uint32_t i=0;i<256;i++)
 	{
-		uint8_t codeBits=readByte()+1;
+		uint8_t codeBits{uint8_t(readByte()+1)};
 		if (!codeBits) continue;
-		if (codeBits>32) throw Decompressor::DecompressionError();
-		uint32_t code=0;
-		int32_t shift=-codeBits;
+		if (codeBits>32)
+			throw Decompressor::DecompressionError();
+		uint32_t code{0};
+		int32_t shift{-codeBits};
 		for (uint32_t j=0;j<codeBits;j+=8)
 		{
 			code=(code<<8)|readByte();
 			shift+=8;
 		}
 		code=(code>>shift)&((1<<codeBits)-1);
-		decoder.insert(HuffmanCode<uint32_t>{codeBits,code,i});
+		decoder.insert(HuffmanCode{codeBits,code,uint8_t(i)});
 	}
 
 	while (!outputStream.eof())
