@@ -17,7 +17,7 @@ PPDecompressor::PPState::PPState(uint32_t mode) noexcept :
 	// nothing needed
 }
 
-bool PPDecompressor::detectHeader(uint32_t hdr) noexcept
+bool PPDecompressor::detectHeader(uint32_t hdr,uint32_t footer) noexcept
 {
 	return hdr==FourCC("PP11") || hdr==FourCC("PP20") || hdr==FourCC("PX20")
 		|| hdr==FourCC("CHFC")		// Sky High Stuntman
@@ -50,7 +50,7 @@ PPDecompressor::PPDecompressor(const Buffer &packedData,bool exactSizeKnown,bool
 	_dataStart=_packedData.size()-4;
 
 	uint32_t hdr{packedData.readBE32(0)};
-	if (!detectHeader(hdr))
+	if (!detectHeader(hdr,0))
 		throw InvalidFormatError(); 
 	if (hdr==FourCC("PX20"))
 	{
@@ -182,7 +182,7 @@ size_t PPDecompressor::getRawSize() const noexcept
 
 	Since the actual decompression is 32-bit xor, it would also be beneficial to do just a histogram
 	with 4 buckets. However, the input files are pretty short and PP algorithm is very good at mangling
-	bytes and bits so there is not neccessarily enough data to get a good idea of the key.
+	bytes and bits so there is not necessarily enough data to get a good idea of the key.
 
 	Going through the 32-bit keyspace is not complicated in itself either. The only complication
 	is that since there are not checksum for the output, the only way to validate the key is to check that
