@@ -5,6 +5,9 @@
 
 #include <cstdint>
 
+namespace ancient::internal
+{
+
 // used by too many compressors...
 class RangeDecoder
 {
@@ -12,14 +15,14 @@ public:
 	class BitReader
 	{
 	public:
-		BitReader();
-		virtual ~BitReader();
+		BitReader() noexcept=default;
+		virtual ~BitReader() noexcept=default;
 		
 		virtual uint32_t readBit()=0;
 	};
 
 	RangeDecoder(BitReader &bitReader,uint16_t initialValue);
-	~RangeDecoder();
+	~RangeDecoder() noexcept=default;
 
 	uint16_t decode(uint16_t length);
 	void scale(uint16_t newLow,uint16_t newHigh,uint16_t newRange);
@@ -27,9 +30,11 @@ public:
 private:
 	BitReader			&_bitReader;
 
-	uint16_t			_low=0;
-	uint16_t			_high=0xffffU;
+	uint16_t			_low{0};
+	uint16_t			_high{0xffffU};
 	uint16_t			_stream;
 };
 
+}
+
 #endif
