@@ -23,75 +23,67 @@ std::shared_ptr<XPKDecompressor> SDHCDecompressor::create(uint32_t hdr,uint32_t
 }
 
 SDHCDecompressor::SDHCDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify) :
-	XPKDecompressor(recursionLevel),
-	_packedData(packedData)
+	XPKDecompressor{recursionLevel},
+	_packedData{packedData}
 {
 	if (!detectHeaderXPK(hdr) || _packedData.size()<2)
 		throw Decompressor::InvalidFormatError();
 	_mode=_packedData.readBE16(0);
 	if (verify && (_mode&0x8000U))
 	{
-		ConstSubBuffer src(_packedData,2,_packedData.size()-2);
-		XPKMain main(src,_recursionLevel+1,true);
+		ConstSubBuffer src{_packedData,2U,_packedData.size()-2U};
+		XPKMain::createDecompressor(_recursionLevel+1,src,true);
 	}
 }
 
-SDHCDecompressor::~SDHCDecompressor()
-{
-	// nothing needed
-}
-
 const std::string &SDHCDecompressor::getSubName() const noexcept
 {
-	static std::string name="XPK-SDHC: Sample delta huffman compressor";
+	static std::string name{"XPK-SDHC: Sample delta huffman compressor"};
 	return name;
 }
 
 void SDHCDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify)
 {
-	ConstSubBuffer src(_packedData,2,_packedData.size()-2);
+	ConstSubBuffer src{_packedData,2U,_packedData.size()-2U};
 	if (_mode&0x8000U)
 	{
-		XPKMain main(src,_recursionLevel+1,false);
-		main.decompress(rawData,verify);
+		auto main=XPKMain::createDecompressor(_recursionLevel+1,src,verify);
+		main->decompress(rawData,verify);
 	} else {
-		if (src.size()!=rawData.size()) throw Decompressor::DecompressionError();
+		if (src.size()!=rawData.size())
+			throw Decompressor::DecompressionError();
 		std::memcpy(rawData.data(),src.data(),src.size());
 	}
 
-	size_t length=rawData.size()&~3U;
+	size_t length{rawData.size()&~3U};
 
 	auto deltaDecodeMono=[&]()
 	{
-		uint8_t *buf=rawData.data();
-
-		uint16_t ctr=0;
+		uint16_t ctr{0};
 		for (size_t i=0;i<length;i+=2)
 		{
 			uint16_t tmp;
-			tmp=(uint16_t(buf[i])<<8)|uint16_t(buf[i+1]);
+			tmp=(uint16_t(rawData[i])<<8U)|rawData[i+1U];
 			ctr+=tmp;
-			buf[i]=ctr>>8;
-			buf[i+1]=ctr&0xff;
+			rawData[i]=ctr>>8U;
+			rawData[i+1U]=ctr&0xffU;
 		}
 	};
 
 	auto deltaDecodeStereo=[&]()
 	{
-		uint8_t *buf=rawData.data();
-
-		uint16_t ctr1=0,ctr2=0;
+		uint16_t ctr1{0};
+		uint16_t ctr2{0};
 		for (size_t i=0;i<length;i+=4)
 		{
-			uint16_t tmp;
-			tmp=(uint16_t(buf[i])<<8)|uint16_t(buf[i+1]);
+			uint16_t tmp{uint16_t((uint16_t(rawData[i])<<8U)|rawData[i+1U])};
 			ctr1+=tmp;
-			tmp=(uint16_t(buf[i+2])<<8)|uint16_t(buf[i+3]);
+			tmp=(uint16_t(rawData[i+2U])<<8U)|rawData[i+3U];
 			ctr2+=tmp;
-			buf[i]=ctr1>>8;
-			buf[i+1]=ctr1&0xff;
-			buf[i+2]=ctr2>>8;
-			buf[i+3]=ctr2&0xff;
+			rawData[i]=ctr1>>8U;
+			rawData[i+1U]=ctr1&0xffU;
+			rawData[i+2U]=ctr2>>8U;
+			rawData[i+3U]=ctr2&0xffU;
 		}
 	};
 
@@ -99,21 +91,21 @@ void SDHCDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData
 	{
 		case 1:
 		DLTADecode::decode(rawData,rawData,0,length);
-		// intentional fall through
+		[[fallthrough]];
 		case 0:
 		DLTADecode::decode(rawData,rawData,0,length);
 		break;
 		
 		case 3:
 		deltaDecodeMono();
-		// intentional fall through
+		[[fallthrough]];
 		case 2:
 		deltaDecodeMono();
 		break;
 
 		case 11:
 		deltaDecodeStereo();
-		// intentional fall through
+		[[fallthrough]];
 		case 10:
 		deltaDecodeStereo();
 		break;
