@@ -21,29 +21,26 @@ std::shared_ptr<XPKDecompressor> SMPLDecompressor::create(uint32_t hdr,uint32_t
 }
 
 SMPLDecompressor::SMPLDecompressor(uint32_t hdr,uint32_t recursionLevel,const Buffer &packedData,std::shared_ptr<XPKDecompressor::State> &state,bool verify) :
-	XPKDecompressor(recursionLevel),
-	_packedData(packedData)
+	XPKDecompressor{recursionLevel},
+	_packedData{packedData}
 {
-	if (!detectHeaderXPK(hdr) || packedData.size()<2) throw Decompressor::InvalidFormatError();
+	if (!detectHeaderXPK(hdr) || packedData.size()<2)
+		throw Decompressor::InvalidFormatError();
 
-	if (packedData.readBE16(0)!=1) throw Decompressor::InvalidFormatError();
-}
-
-SMPLDecompressor::~SMPLDecompressor()
-{
-	// nothing needed
+	if (packedData.readBE16(0)!=1U)
+		throw Decompressor::InvalidFormatError();
 }
 
 const std::string &SMPLDecompressor::getSubName() const noexcept
 {
-	static std::string name="XPK-SMPL: Huffman compressor with delta encoding";
+	static std::string name{"XPK-SMPL: Huffman compressor with delta encoding"};
 	return name;
 }
 
 void SMPLDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData,bool verify)
 {
-	ForwardInputStream inputStream(_packedData,2,_packedData.size());
-	MSBBitReader<ForwardInputStream> bitReader(inputStream);
+	ForwardInputStream inputStream{_packedData,2U,_packedData.size()};
+	MSBBitReader<ForwardInputStream> bitReader{inputStream};
 	auto readBits=[&](uint32_t count)->uint32_t
 	{
 		return bitReader.readBits8(count);
@@ -53,23 +50,23 @@ void SMPLDecompressor::decompressImpl(Buffer &rawData,const Buffer &previousData
 		return bitReader.readBits8(1);
 	};
 
-	ForwardOutputStream outputStream(rawData,0,rawData.size());
+	ForwardOutputStream outputStream{rawData,0,rawData.size()};
 
 	HuffmanDecoder<uint32_t> decoder;
 
 	for (uint32_t i=0;i<256;i++)
 	{
-		uint32_t codeLength=readBits(4);
+		uint32_t codeLength{readBits(4U)};
 		if (!codeLength) continue;
-		if (codeLength==15) codeLength=readBits(4)+15;
-		uint32_t code=readBits(codeLength);
-		decoder.insert(HuffmanCode<uint32_t>{codeLength,code,i});
+		if (codeLength==15) codeLength=readBits(4U)+15U;
+		uint32_t code{readBits(codeLength)};
+		decoder.insert(HuffmanCode{codeLength,code,i});
 	}
 
-	uint8_t accum=0;
+	uint8_t accum{0};
 	while (!outputStream.eof())
 	{
-		uint32_t code=decoder.decode(readBit);
+		uint32_t code{decoder.decode(readBit)};
 		accum+=code;
 		outputStream.writeByte(accum);
 	}
