@@ -7,6 +7,9 @@
 
 #include "Buffer.hpp"
 
+namespace ancient::internal
+{
+
 // The most common CRC32
 
 uint32_t CRC32(const Buffer &buffer,size_t offset,size_t len,uint32_t accumulator);
@@ -19,4 +22,6 @@ uint32_t CRC32Rev(const Buffer &buffer,size_t offset,size_t len,uint32_t accumul
 
 uint32_t CRC32RevByte(uint8_t ch,uint32_t accumulator) noexcept;
 
+}
+
 #endif
